flutter_aepoptimize_data library

Classes

DecisionScope
Represents a scope used to fetch personalization decisions (propositions) from the Edge Network.
Offer
Represents a decision option (offer) contained within an OptimizeProposition.
OptimizeProposition
Represents the propositions received from the Edge Network for a given DecisionScope.

Enums

OfferType
Enum representing the type of an Offer's content.

Extensions

OfferTypeExtension on OfferType
Convenience accessors that map an OfferType to the values used by the native SDK.
OfferTypeFromInt on int
Maps an integer received from the native SDK back to an OfferType.